#
# spec file for package openvas-scanner
#
# Copyright (c) 2011 SUSE LINUX Products GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           openvas-scanner
Version:        3.4.0
Release:        4.4
License:        GPL-2.0
Group:          Productivity/Networking/Security
URL:            http://www.openvas.org
Source0:        %{name}-%{version}.tar.gz
Source1:        openvassd.logrotate
Source2:        debian.openvas-scanner.default
Source3:        openvassd.init.suse
Source4:        openvassd.init.fedora
Source5:        openvassd.init.mandriva
Source6:	openvas-scanner.service
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%if 0%{?mandriva_version}
BuildRequires:  pinentry-gtk2
%endif

%if 0%{?suse_version}
PreReq:         %insserv_prereq
PreReq:         %fillup_prereq
%if 0%{?suse_version} > 1220
BuildRequires:  systemd
%systemd_requires
%endif
%endif

BuildRequires:  cmake
BuildRequires:  glib2-devel
BuildRequires:  libopenvas-devel >= 5.0.0
BuildRequires:  libgcrypt-devel
BuildRequires:  pkgconfig
Requires:       logrotate
Requires:       openssl
Requires:       rsync
Requires:	openvas-scanner-doc
Summary:        The Scanner Module for OpenVAS

%description
This is the scanner module for the Open Vulnerability Assessment System (OpenVAS).

%package doc
Summary:        Additional Package Documentation
Group:          Documentation/Other
BuildArch:      noarch

%description doc
This package contains optional documentation provided in addition to
this package's base documentation.

%prep
%setup -q

%build
%if 0%{?mandriva_version}
%serverbuild
%endif

export CFLAGS="$RPM_OPT_FLAGS"

cmake -DCMAKE_VERBOSE_MAKEFILE=ON \
        -DCMAKE_INSTALL_PREFIX=%{_prefix} \
        -DSYSCONFDIR=%{_sysconfdir} \
        -DLIBDIR=%{_libdir} \
        -DLOCALSTATEDIR=%{_localstatedir} \
        -DCMAKE_BUILD_TYPE=release
%__make %{?_smp_mflags}

%install
%__make install DESTDIR=%{buildroot}
%__install -Dm 0644 %{_sourcedir}/openvassd.logrotate %{buildroot}%{_sysconfdir}/logrotate.d/openvas-scanner

%if 0%{?suse_version}
%__install -Dm 0755 %{_sourcedir}/openvassd.init.suse %{buildroot}%{_initrddir}/openvas-scanner
%__ln_s %{_initrddir}/openvas-scanner %{buildroot}%{_sbindir}/rcopenvas-scanner
%__install -Dm 0644 %{_sourcedir}/debian.openvas-scanner.default %{buildroot}%{_var}/adm/fillup-templates/sysconfig.openvas-scanner
%if 0%{?suse_version} > 1220
mkdir -p $RPM_BUILD_ROOT/usr/lib/systemd/
mkdir -p $RPM_BUILD_ROOT/usr/lib/systemd/system
install -m 644 $RPM_SOURCE_DIR/openvas-scanner.service $RPM_BUILD_ROOT/usr/lib/systemd/system/openvas-scanner.service
%endif
%__ln_s %{_mandir}/man8/openvas-mkcert.8.gz %{buildroot}%{_mandir}/man8/openvas-mkcert-client.8.gz
%endif

%if 0%{?fedora_version} || 0%{?scientificlinux_version} || 0%{?centos_version}
%__install -Dm 0755 %{_sourcedir}/openvassd.init.fedora %{buildroot}%{_initrddir}/openvas-scanner
%__install -Dm 0644 %{_sourcedir}/debian.openvas-scanner.default %{buildroot}%{_sysconfdir}/sysconfig/openvas-scanner
%endif

%if 0%{?mandriva_version}
%__install -Dm 0755 %{_sourcedir}/openvassd.init.mandriva %{buildroot}%{_initrddir}/openvas-scanner
%__install -Dm 0644 %{_sourcedir}/debian.openvas-scanner.default %{buildroot}%{_sysconfdir}/sysconfig/openvas-scanner
%endif

%__mkdir_p %{buildroot}%{_localstatedir}/cache/openvas
%__mkdir_p %{buildroot}%{_localstatedir}/lib/openvas
%__mkdir_p %{buildroot}%{_localstatedir}/log/openvas
touch %{buildroot}%{_localstatedir}/log/openvas/greenbone-nvt-sync.log
touch %{buildroot}%{_localstatedir}/log/openvas/openvassd.dump
touch %{buildroot}%{_localstatedir}/log/openvas/openvassd.messages

%clean
test "%{buildroot}" != "/" && %__rm -rf %{buildroot}

%pre
%if 0%{?suse_version} > 1220
%service_add_pre openvas-scanner.service
%endif

%post
# Generate cert
if [ ! -f  %{_localstatedir}/lib/openvas/CA/servercert.pem ] ; then
	%{_sbindir}/openvas-mkcert -q > /dev/null 2>&1
fi

%if 0%{?suse_version}
%fillup_and_insserv openvas-scanner
%if 0%{?suse_version} > 1220
%service_add_post openvas-scanner.service
%endif
%endif

%if 0%{?mandriva_version}
%_post_service openvas-scanner
%endif

%if 0%{?fedora_version} || 0%{?scientificlinux_version} || 0%{?centos_version}
# only rpm -i (not rpm {-U|-F})
if [ $1 = 1 ]; then
	/sbin/chkconfig --add openvas-scanner
fi
%endif

%preun
%if 0%{?suse_version}
%stop_on_removal openvas-scanner
%if 0%{?suse_version} > 1220
%service_del_preun openvas-scanner.service 
%endif
%endif

%if 0%{?mandriva_version}
%_preun_service openvas-scanner
%endif

%if 0%{?fedora_version} || 0%{?scientificlinux_version} || 0%{?centos_version}
# only rpm -e (not rpm {-U|-F})
if [ $1 = 0 ]; then
    /sbin/service openvas-scanner stop > /dev/null 2>&1 || :
    /sbin/chkconfig --del openvas-scanner
fi
%endif

%postun
%if 0%{?suse_version}
%restart_on_update openvas-scanner
%insserv_cleanup
%if 0%{?suse_version} > 1220
%service_del_postun openvas-scanner.service
%endif
%endif

%if 0%{?fedora_version} || 0%{?scientificlinux_version} || 0%{?centos_version}
# only rpm {-U|-F} (not rpm -e)
if [ $1 = 1 ]; then
    /sbin/service openvas-scanner condrestart
fi
%endif

%files
%defattr(-,root,root)
%config(noreplace) %{_sysconfdir}/logrotate.d/openvas-scanner
%{_initrddir}/openvas-scanner
%{_sbindir}/greenbone-nvt-sync
%{_sbindir}/openvas-adduser
%{_sbindir}/openvas-mkcert
%{_sbindir}/openvas-mkcert-client
%{_sbindir}/openvas-nvt-sync
%{_sbindir}/openvas-rmuser
%{_sbindir}/openvassd
%ghost %{_localstatedir}/cache/openvas
%dir %{_localstatedir}/lib/openvas
%dir %{_localstatedir}/log/openvas
%ghost %{_localstatedir}/log/openvas/greenbone-nvt-sync.log
%ghost %{_localstatedir}/log/openvas/openvassd.dump
%ghost %{_localstatedir}/log/openvas/openvassd.messages
%{_mandir}/man8/greenbone-nvt-sync.8*
%{_mandir}/man8/openvas-adduser.8*
%{_mandir}/man8/openvas-mkcert.8*
%{_mandir}/man8/openvas-nvt-sync.8*
%{_mandir}/man8/openvas-rmuser.8*
%{_mandir}/man8/openvassd.8*
%{_mandir}/man8/openvas-mkcert-client.8*
%if 0%{?suse_version}
%{_sbindir}/rcopenvas-scanner
%{_var}/adm/fillup-templates/sysconfig.openvas-scanner
%if 0%{?suse_version} > 1220
   /usr/lib/systemd/system/openvas-scanner.service
%endif
%else
%config(noreplace) %{_sysconfdir}/sysconfig/openvas-scanner
%endif

%files doc
%defattr(-,root,root)
%doc CHANGES COPYING ChangeLog README
%changelog
* Wed Aug 28 2013 johann.luce@wanadoo.fr
- Fix OBS Warning
* Tue Aug 27 2013 johann.luce@wanadoo.fr
- Adding systemd native init script
- Adding doc package
- Cleaning spec files
* Thu Apr 18 2013 johann.luce@wanadoo.fr
- Update to 3.4.0 (first release for OpenVAS-6)
  * Minimum requirements for openvas-libraries: Increased from 5.0 to 6.0.
  * Minimum requirements for GnuTLS: Increased from 2.2 to 2.8.
  * New optional OTP version 1.1 which is like 1.0 but sends less info
    to the client initially.
  * Changed behaviour of NVT sync script "openvas-nvt-sync":
    It will now delete scripts not part of the when using rsync,
    except for the directory "private/".
  * A Migration option "--migrate-to-private" of the sync-script will
    move private scripts into the "private/" directory.
    The Feed Sync will stop with an error until the "private/" is created.
    As soon as this directory is created, the synchronisation will ultimately
    delete all files in the local feed directory that are not part of the
    regular Feed.
  * Changed: The magic that NVTs of category ACT_SETTINGS were always enabled
    even when user disabled them has been removed. OTP clients now have
    to take care to enable as needed.
  * Send NODESC and NOSUMMARY instead of whole plugin description and summary when
    no result is returned and plugin has all new nvt tags.
  * Newline in script tags are now escaped.
  * The size of tags is not limited anymore.
  * Internal use of NVTI references by OID to allow using the NVTI
    cache properly. This significantly lowers the memory consumption
    per Scanner process.
  * Improve bug tracking by directing diagnostics to the log file.
  * Removed deprecated code.
  * Various code and build cleanups.
  * Removed built-in logfile rotation. It is not a good idea to try
    to circumvent system environment technology for logrotate.
  * New command line switch "--only-cache" to just build the cache and exit.
  * Fixed a bug when NVT lacks family specification.
  * Add private directory for RSYNC_DELETE to greenbone-nvt-sync.
  * Improve bug tracking by directing diagnostics to the log file.
  * Internal code cleanups for NVTI cache handling.
  * Fixed a bug when NVT lacks family specification.
  * Closed a number of memory leaks.
* Sat May 12 2012 bitshuffler@opensuse.org
- Updated to 3.3.1
  * The CMake infrastructure has been cleaned up to ensure that compilation with
    modern gccs works.
  * The greenbone-nvt-sync script has been updated.
  * OpenVAS Scanner now requires at least glib 2.16 and gnutls 2.2, matching the
    requirements of OpenVAS Libraries.
  * New scanner preference "reverse_lookup", defaulting to "no" (the previous
    behaviour)
  * For network wide scanning, mandatory keys are ignored.
  * Don't start the second scan phase when network scan is enabled and
    user requests "stop" during the first phase.
  * Send an ERRMSG to the client when terminating a process.
  * Furter improvements to the build system.
* Sat Nov 12 2011 bitshuffler@opensuse.org
- Updated to 3.3+beta2
  * NVT management code has been updated to reflect the updated openvas-libraries
    API.
  * The optional use of the external tool "ovaldi" has been made more secure.
  * OpenVAS Scanner now uses UTC internally.
  * The greenbone-nvt-sync script has been updated.
  * Changed: Do not force execution of ACT_INIT category.
  * Fixed: A number of potential resource leaks.
  * Fixed: A number of compiler warnings when compiling with gcc 4.6.
  * Fixed: Usage of the mktemp template in openvas-nvt-sync.
  * Removed: Support for shared sockets.
  * New: The scanner options "network_scan" and "report_host_details" have been
    added to the default scanner options.
* Fri Nov  4 2011 bitshuffler@opensuse.org
- Updated to 3.2.5
  * The optional use of the external tool "ovaldi" has been made more secure.
* Thu Aug 25 2011 crrodriguez@opensuse.org
- Fix build.
* Wed Jun  8 2011 bitshuffler@opensuse.org
- Updated to 3.2.4
  * Fixed: Two potential resource leaks.
  * Fixed: A number of compiler warning when compiling with gcc 4.6.
  * Fixed: Usage of the mktemp template in openvas-nvt-sync.
* Mon Apr 11 2011 bitshuffler@opensuse.org
- Updated to 3.2.3
  * Fixed: Three potential resource leaks.
  * Fixed: Generation of code documentation.
  * Updated: Feed synchronization scripts.
  * Changed: The openvas-nvt-sync script will now perform the initial feed
    synchronization via HTTP instead of rsync.
  * Changed: The openvas-nvt-sync script will now default to synchronize into the
    NVT directory used by the OpenVAS Scanner instead of the one defined at
    compile time.
* Wed Feb 23 2011 bitshuffler@opensuse.org
- Updated to 3.2.2
  * The last bashism has been removed from the openvas-nvt-sync synchronization
    script.
  * The greenbone-nvt-sync script now logs additional information during
    synchronization.
  * An unimplemented and superfluous function declaration has been removed.
  * The openvassd man page has been updated.
  * The build environment has been consolidated.
  * The greenbone-nvt-sync script has been improved.
  * OpenVAS Scanner now sets a default value for the "unscanned_closed"
    preference.
* Fri Feb  4 2011 bitshuffler@opensuse.org
- Updated to 3.2.0
  * The sync scripts have been updated.
  * OpenVAS Scanner now uses pkg-config to find libraries.
  * Installation of the openvas-services file has been moved to openvas-libraries.
  * Filesystem Hierarchy Standard (FHS 2.3) compliance has been improved.
* Wed Jan 26 2011 bitshuffler@opensuse.org
- Updated to 3.1.99.2
  * Improved output of --version
  * Comprehensive code cleanup
  * Binary (.nes) plugins we moved to libraries and turned into builtin
    NASL methods.
  * Removed handling of binary plugins as we don't want to have them ever
    again.
  * Added preferences for the vhost feature so that clients get them
    and can offer them to the user. In other words: unhide the vhost feature.
  * Default port is now 9391 where the OpenVAS Manager expects the
    Scanner by default.
  * Command line options "--dump-cfg" and "--gen-config" are removed.
  * openvassd does not need anymore a "openvassd.conf" file. It uses
    its defaults and a possibly present conf-file can overwrite settings.
  * openvas-mkcert got a additional switch "-f" to force overwriting
    certificates.
  * openvas-mkcert does not create a openvassd.conf anymore as it shares
    the defaults with openvassd.
* Mon Dec 20 2010 bitshuffler@opensuse.org
- Updated to 3.1.99.1
  * Debug messages during the use of shared sockets are no longer logged unless
    requested during compile time.
  * A number of compiler warnings from gcc 4.4 has been addressed.
  * Hardening flags are now enabled during compile time to increase code quality.
  * openvas-scanner now listens on an IPv4 socket by default, even when IPv6
    support is present.
* Mon Dec  6 2010 bitshuffler@opensuse.org
- Updated to 3.1.98.2
  * A compiler warning regarding an incorrect function declaration in
    openvas_tcp_scanner has been addressed.
  * A compiler warning regarding incorrect pointer casts in find_service has been
    addressed.
  * A compiler warning regarding the type of a return value in openvassd has been
    addressed.
  * An issue which caused openvassd to refuse to scan certain hosts even when
    permitted by rules has been fixed.
  * An issue which caused openvassd to abort the scan process prematurely under
    certain circumstances has been fixed.
* Fri Dec  3 2010 bitshuffler@opensuse.org
- Updated to 3.1.98.1
  * Network level scan support.
  * Removed unnecessary log entries.
  * Include paths have been updated to match with openvas-libraries 4.0.
* Sun Oct 31 2010 bitshuffler@opensuse.org
- Updated to 3.1.1
  * The code documentation infrastructure has been improved.
  * The license situation of the individual source code files has been clarified.
  * Obsolete support for systems without entropy generation has been removed.
  * A bug which caused the client certificate generation to fail under certain
    circumstances has been fixed.
* Wed Jul 14 2010 bitshuffler@opensuse.org
- Updated to 3.1.0
  * Support for storing scanner passwords in plaintext has been removed.
  * Support for dropping privileges in NASL and NES NVTs had been added.
  * Support for scanning virtual web hosts has been added.
  * The handling of NVTs with an invalid timestamp has been improved.
  * A bug in the openvas-nvt-sync script which prevented synchronization via http
    under certain circumstances has been fixed.
  * Support for retrieving the version of the NVT collection has been added to the
    openvas-nvt-sync and greenbone-nvt-sync scripts.
  * Support for soft pausing of scans has been added.
  * Support for automatically installing generated certificate file has been added
    to the openvas-mkcert-client script.
  * The obsolete C based NVT "ssl_cipher" has been removed from the
    openvas-scanner module. It has been replaced by the NASL implementation
    "secpod_ssl_ciphers.nasl".
  * Support for storing an uploaded preference file in memory instead of on disk
    has been added.
* Fri Jul  2 2010 bitshuffler@opensuse.org
- Updated to 3.1.0.rc3
  * Support for storing scanner passwords in plaintext has been removed.
* Mon Jun 28 2010 bitshuffler@opensuse.org
- Updated to 3.1.0.rc2
  * The support scripts for feed synchronization have been updated.
  * Support for dropping privileges in NASL and NES NVTs had been added.
  * Support for scanning virtual web hosts has been added.
  * The handling of NVTs with an invalid timestamp has been improved.
* Wed May 19 2010 bitshuffler@opensuse.org
- Updated to 3.1.0.rc1
  * A bug in the openvas-nvt-sync script which prevented synchronization via http
    under certain circumstances has been fixed.
  * The build environment for C based NVTs has been cleaned up.
  * Code formatting has been improved in a number of files to match the coding
    style.
  * Support for retrieving the version of the NVT collection has been added to the
    openvas-nvt-sync and greenbone-nvt-sync scripts.
  * Support for soft pausing of scans has been added.
  * Support for automatically installing generated certificate file has been added
    to the openvas-mkcert-client script.
  * The obsolete C based NVT "ssl_cipher" has been removed from the
    openvas-scanner module. It has been replaced by the NASL implementation
    "secpod_ssl_ciphers.nasl".
  * Support for storing an uploaded preference file in memory instead of on disk
    has been added.
* Mon Mar 22 2010 bitshuffler@opensuse.org
- Updated to 3.0.2
* Fri Mar 12 2010 felix.wolfsteller@intevation.de
- Added greenbone nvt sync script.
* Fri Feb  5 2010 felix.wolfsteller@intevation.de
- Reenabled Scanner Certificate Creation with openvas-mkcert
  at install time, if no certificate is present already.
* Tue Jan 26 2010 bitshuffler@opensuse.org
- Updated to 3.0.1
* Sun Jan 24 2010 bitshuffler@opensuse.org
- Added %%ghost entries for log files.
- Added /etc/sysconfig/openvas-scanner for configuration
* Fri Jan  8 2010 felix.wolfsteller@intevation.de
- Added patch from  Vladimir Nadvornik fixing wrong NVT directory
  in openvassd.conf on 64-Bit systems.
* Mon Dec 21 2009 felix.wolfsteller@intevation.de
- Added logrotate- dependency.
* Fri Dec 18 2009 felix.wolfsteller@intevation.de
- Updated to version 3.0.0
* Sun Dec  6 2009 felix.wolfsteller@intevation.de
- Added sysconfdir/openvas/gnupg directory to files section.
- Install logrotate and init script to locations that match the package name (suse conditioned).
- Updated to 3.0.0.rc1
* Wed Dec  2 2009 felix.wolfsteller@intevation.de
- Added and install configuration file, uncommented cache and log directories.
* Tue Jun  2 2009 bitshuffler@opensuse.org
- Updated to 2.0.2
* Tue Feb 17 2009 bitshuffler@opensuse.org
- Updated to 2.0.1
* Sat Dec 20 2008 bitshuffler@opensuse.org
- Updated to 2.0.0
* Sun Aug 24 2008 bitshuffler@opensuse.org
- Updated to 1.0.2
* Sun Aug 10 2008 bitshuffler@opensuse.org
- Init.d script added
* Wed Jul  2 2008 bitshuffler@opensuse.org
- Updated to 1.0.1
* Tue Jun 10 2008 bitshuffler@opensuse.org
- Initial RPM
